package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.utils.SecurityUtils;
import io.swagger.annotations.*;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.Result;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TClazz;
import com.ruoyi.system.domain.req.TClazzQueryReq;
import com.ruoyi.system.domain.req.TClazzSaveReq;
import com.ruoyi.system.domain.req.TClazzEditReq;
import com.ruoyi.system.service.TClazzService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
/**
 * 班级管理Controller
 *
 * @author 付凡芮
 * @date 2024-04-22
 */
@Api(tags = "班级管理")
@RestController
@RequestMapping("/system/clazz")
public class TClazzController extends BaseController {
    @Autowired
    private TClazzService tClazzService;

    /**
     * 查询班级管理列表
     */
    @ApiOperation("获取班级管理列表")
    @PreAuthorize("@ss.hasPermi('system:clazz:list')")
    @GetMapping("/list")
    public Result<TableDataInfo<TClazz>> list(TClazzQueryReq tClazzQueryReq) {
        startPage();
        List<TClazz> list = tClazzService.list(TClazz.queryBuild(tClazzQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出班级管理列表
     */
    @ApiOperation("导出班级管理列表")
    @PreAuthorize("@ss.hasPermi('system:clazz:export')")
    @Log(title = "班级管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TClazz tClazz) {
        List<TClazz> list = tClazzService.list(tClazz);
        ExcelUtil<TClazz> util = new ExcelUtil<TClazz>(TClazz.class);
        util.exportExcel(response, list, "班级管理数据");
    }

    /**
     * 获取班级管理详细信息
     */
    @ApiOperation("获取班级管理详细信息")
    @PreAuthorize("@ss.hasPermi('system:clazz:query')")
    @GetMapping(value = "/{clazzId}")
    @ApiImplicitParam(name = "clazzId", value = "clazzId", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<TClazz> getInfo(@PathVariable("clazzId") Long clazzId) {
        return Result.success(tClazzService.getById(clazzId));
    }

    /**
     * 新增班级管理
     */
    @PreAuthorize("@ss.hasPermi('system:clazz:add')")
    @Log(title = "班级管理", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增班级管理")
    public Result<String> add(@RequestBody TClazzSaveReq tClazzSaveReq) {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        String username = loginUser.getUsername();
        tClazzSaveReq.setClazzFounder(username);
        return toAjax(tClazzService.save(TClazz.saveBuild(tClazzSaveReq)));
    }

    /**
     * 修改班级管理
     */
    @PreAuthorize("@ss.hasPermi('system:clazz:edit')")
    @Log(title = "班级管理", businessType = BusinessType.UPDATE)
    @PutMapping("/{clazzId}")
    @ApiOperation("修改班级管理")
    public Result<String> edit(@PathVariable Long clazzId, @RequestBody TClazzEditReq tClazzEditReq) {
        return toAjax(tClazzService.updateById(TClazz.editBuild(clazzId,tClazzEditReq)));
    }

    /**
     * 删除班级管理
     */
    @PreAuthorize("@ss.hasPermi('system:clazz:remove')")
    @Log(title = "班级管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{clazzIds}")
    @ApiOperation("删除班级管理")
    @ApiImplicitParam(name = "clazzId", value = "clazzId", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> clazzIds) {
        return toAjax(tClazzService.removeBatchByIds(clazzIds));
    }
}
