package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.*;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.Result;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TGroup;
import com.ruoyi.system.domain.req.TGroupQueryReq;
import com.ruoyi.system.domain.req.TGroupSaveReq;
import com.ruoyi.system.domain.req.TGroupEditReq;
import com.ruoyi.system.service.TGroupService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 班级小组管理Controller
 *
 * @author 付凡芮
 * @date 2024-04-23
 */
@Api(tags = "班级小组管理")
@RestController
@RequestMapping("/system/group")
public class TGroupController extends BaseController {
    @Autowired
    private TGroupService tGroupService;

    /**
     * 查询班级小组管理列表
     */
    @ApiOperation("获取班级小组管理列表")
    @PreAuthorize("@ss.hasPermi('system:group:list')")
    @GetMapping("/list")
    public Result<TableDataInfo<TGroup>> list(TGroupQueryReq tGroupQueryReq) {
        startPage();
        List<TGroup> list = tGroupService.list(TGroup.queryBuild(tGroupQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出班级小组管理列表
     */
    @ApiOperation("导出班级小组管理列表")
    @PreAuthorize("@ss.hasPermi('system:group:export')")
    @Log(title = "班级小组管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TGroup tGroup) {
        List<TGroup> list = tGroupService.list(tGroup);
        ExcelUtil<TGroup> util = new ExcelUtil<TGroup>(TGroup.class);
        util.exportExcel(response, list, "班级小组管理数据");
    }

    /**
     * 获取班级小组管理详细信息
     */
    @ApiOperation("获取班级小组管理详细信息")
    @PreAuthorize("@ss.hasPermi('system:group:query')")
    @GetMapping(value = "/{groupId}")
    @ApiImplicitParam(name = "groupId", value = "groupId", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<TGroup> getInfo(@PathVariable("groupId") Long groupId) {
        return Result.success(tGroupService.getById(groupId));
    }

    /**
     * 新增班级小组管理
     */
    @PreAuthorize("@ss.hasPermi('system:group:add')")
    @Log(title = "班级小组管理", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增班级小组管理")
    public Result<String> add(@RequestBody TGroupSaveReq tGroupSaveReq) {
        return toAjax(tGroupService.save(TGroup.saveBuild(tGroupSaveReq)));
    }

    /**
     * 修改班级小组管理
     */
    @PreAuthorize("@ss.hasPermi('system:group:edit')")
    @Log(title = "班级小组管理", businessType = BusinessType.UPDATE)
    @PutMapping("/{groupId}")
    @ApiOperation("修改班级小组管理")
    public Result<String> edit(@PathVariable Long groupId, @RequestBody TGroupEditReq tGroupEditReq) {
        return toAjax(tGroupService.updateById(TGroup.editBuild(groupId,tGroupEditReq)));
    }

    /**
     * 删除班级小组管理
     */
    @PreAuthorize("@ss.hasPermi('system:group:remove')")
    @Log(title = "班级小组管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{groupIds}")
    @ApiOperation("删除班级小组管理")
    @ApiImplicitParam(name = "groupId", value = "groupId", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> groupIds) {
        return toAjax(tGroupService.removeBatchByIds(groupIds));
    }
}
